@@ -22,7 +22,9 @@ def cli(ctx):
               callback=validate_version_version)
 def create_version(version):
     """ Create a new version for django project """
-    message, result = createVersion(version=version)
+    message, result = createVersion(version=version,
+                                    project_name=project_name,
+                                    old_versions=versions)
     if result == True:
         message = f"Se creó version '{version}' correctamente"
         click.secho(message, fg='green')
