@@ -6,6 +6,8 @@ import shutil
 import random
 import string
 
+import pkgutil
+
 
 def appendContent(path, content, find=None, recursive=False):
     '''
@@ -593,6 +595,49 @@ def createVersion(version, project_name, old_versions):
     if result == False:
         errors.append([message, True])
 
+    # Crear carpeta API nueva versión con archivos
+    primary_package = "springlabs_pypi"
+    os.chdir("api")
+    new_version = f"v{version}"
+    os.mkdir(new_version)
+    base_urls_py = "/core/new_version/api/baseUrls.py"
+    base_public_urls_py = "/core/new_version/api/basePublicUrls.py"
+    base_private_urls_py = "/core/new_version/api/basePrivateUrls.py"
+    base_serializers_py = "/core/new_version/api/baseSerializers.py"
+    base_views_py = "/core/new_version/api/baseViews.py"
+
+    template_urls_py = pkgutil.get_data(
+        primary_package, base_urls_py).decode('utf-8')
+    template_urls_py = template_urls_py.replace("name_version", new_version)
+
+    template_public_urls_py = pkgutil.get_data(
+        primary_package, base_public_urls_py).decode('utf-8')
+    template_public_urls_py = template_public_urls_py.replace(
+        "name_version", new_version)
+
+    template_private_urls_py = pkgutil.get_data(
+        primary_package, base_private_urls_py).decode('utf-8')
+    template_private_urls_py = template_private_urls_py.replace(
+        "name_version", new_version)
+
+    template_serializers_py = pkgutil.get_data(
+        primary_package, base_serializers_py).decode('utf-8')
+
+    template_views_py = pkgutil.get_data(
+        primary_package, base_views_py).decode('utf-8')
+
+    with open(f"{new_version}/urls.py", "w") as file:
+        file. write(template_urls_py)
+    with open(f"{new_version}/public_urls.py", "w") as file:
+        file. write(template_public_urls_py)
+    with open(f"{new_version}/private_urls.py", "w") as file:
+        file. write(template_private_urls_py)
+    os.mkdir(f"{new_version}/users")
+    with open(f"{new_version}/users/serializers.py", "w") as file:
+        file. write(template_serializers_py)
+    with open(f"{new_version}/users/views.py", "w") as file:
+        file. write(template_views_py)
+
     for error in errors:
         if error[1] == True:
             message, result = reverseChanges(project_name=project_name)
